@@ -284,10 +284,10 @@ gog_child_button_set_object (GogChildButton *child_button, GogObject *gog_object
 static void
 gog_child_button_popup (GogChildButton *child_button, guint button, guint32 event_time)
 {
-	if (!gtk_widget_is_realized (child_button))
+	if (!gtk_widget_get_realized (GTK_WIDGET (child_button)))
 		return;
 
-	if (gtk_widget_is_mapped (child_button->menu))
+	if (gtk_widget_get_mapped (GTK_WIDGET (child_button->menu)))
 		return;
 
 	child_button->button_handling_in_progress = TRUE;
