@@ -19,6 +19,7 @@
  * USA
  */
 #include <goffice/goffice-config.h>
+#include <goffice/gtk/go-gtk-compat.h>
 #include "go-action-combo-stack.h"
 #include "go-combo-box.h"
 #include "goffice-gtk.h"
@@ -54,9 +55,9 @@ enum {
 	KEY_COL
 };
 
-#define GO_COMBO_STACK_TYPE	(go_combo_stack_get_type ())
-#define GO_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_CAST (o, GO_COMBO_STACK_TYPE, GOComboStack)
-#define IS_GO_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_TYPE (o, GO_COMBO_STACK_TYPE)
+#define GO_TYPE_COMBO_STACK	(go_combo_stack_get_type ())
+#define GO_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_CAST (o, GO_TYPE_COMBO_STACK, GOComboStack)
+#define GO_IS_COMBO_STACK(o)	G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TYPE_COMBO_STACK)
 
 static GType go_combo_stack_get_type   (void);
 static guint go_combo_stack_signals [LAST_SIGNAL] = { 0, };
@@ -162,7 +163,7 @@ go_combo_stack_init (GOComboStack *stack)
 
 	stack->button = gtk_toggle_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (stack->button), GTK_RELIEF_NONE);
-	GTK_WIDGET_UNSET_FLAGS (stack->button, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (stack->button, FALSE);
 
 	stack->list = (GtkTreeView *)gtk_tree_view_new ();
 	selection = gtk_tree_view_get_selection (stack->list);
@@ -214,7 +215,7 @@ go_combo_stack_class_init (GObjectClass *klass)
 
 GSF_CLASS (GOComboStack, go_combo_stack,
 	   go_combo_stack_class_init, go_combo_stack_init,
-	   GO_COMBO_BOX_TYPE)
+	   GO_TYPE_COMBO_BOX)
 
 /**************************************************************************/
 
@@ -224,9 +225,9 @@ typedef struct {
 } GOToolComboStack;
 typedef GtkToolItemClass GOToolComboStackClass;
 
-#define GO_TOOL_COMBO_STACK_TYPE	(go_tool_combo_stack_get_type ())
-#define GO_TOOL_COMBO_STACK(o)		(G_TYPE_CHECK_INSTANCE_CAST (o, GO_TOOL_COMBO_STACK_TYPE, GOToolComboStack))
-#define IS_GO_TOOL_COMBO_STACK(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TOOL_COMBO_STACK_TYPE))
+#define GO_TYPE_TOOL_COMBO_STACK	(go_tool_combo_stack_get_type ())
+#define GO_TOOL_COMBO_STACK(o)		(G_TYPE_CHECK_INSTANCE_CAST (o, GO_TYPE_TOOL_COMBO_STACK, GOToolComboStack))
+#define GO_IS_TOOL_COMBO_STACK(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TYPE_TOOL_COMBO_STACK))
 
 static GType go_tool_combo_stack_get_type (void);
 
@@ -290,13 +291,13 @@ go_action_combo_stack_create_tool_item (GtkAction *a)
 	GOActionComboStack *saction = (GOActionComboStack *)a;
 	GtkWidget *image;
 	GtkTreeView *tree_view;
-	GOToolComboStack *tool = g_object_new (GO_TOOL_COMBO_STACK_TYPE, NULL);
+	GOToolComboStack *tool = g_object_new (GO_TYPE_TOOL_COMBO_STACK, NULL);
 	char *stock_id;
 	gboolean is_sensitive = gtk_tree_model_iter_n_children (saction->model, NULL) > 0;
 	GtkIconSize size;
 	GtkSettings *settings;
 
-	tool->combo = g_object_new (GO_COMBO_STACK_TYPE, NULL);
+	tool->combo = g_object_new (GO_TYPE_COMBO_STACK, NULL);
 	tree_view = GTK_TREE_VIEW (tool->combo->list);
 	gtk_tree_view_set_model (tree_view, saction->model);
 	gtk_tree_view_set_headers_visible (tree_view, FALSE);
@@ -395,10 +396,10 @@ check_sensitivity (GOActionComboStack *saction, unsigned old_count)
  * @key : a key value to id the pushe item
  **/
 void
-go_action_combo_stack_push (GOActionComboStack *a,
+go_action_combo_stack_push (GOActionComboStack *act,
 			    char const *label, gpointer key)
 {
-	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (a);
+	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (act);
 	GtkTreeIter iter;
 	unsigned old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
 
@@ -421,9 +422,9 @@ go_action_combo_stack_push (GOActionComboStack *a,
  * shorter)
  **/
 void
-go_action_combo_stack_pop (GOActionComboStack *a, unsigned n)
+go_action_combo_stack_pop (GOActionComboStack *act, unsigned n)
 {
-	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (a);
+	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (act);
 	GtkTreeIter iter;
 	unsigned old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
 
@@ -445,14 +446,16 @@ go_action_combo_stack_pop (GOActionComboStack *a, unsigned n)
  * bottom.
  **/
 void
-go_action_combo_stack_truncate (GOActionComboStack *a, unsigned n)
+go_action_combo_stack_truncate (GOActionComboStack *act, unsigned n)
 {
-	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (a);
+	GOActionComboStack *saction = GO_ACTION_COMBO_STACK (act);
 	GtkTreeIter iter;
-	unsigned old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
+	unsigned old_count;
 
 	g_return_if_fail (saction != NULL);
 
+	old_count = gtk_tree_model_iter_n_children (saction->model, NULL);
+
 	if (gtk_tree_model_iter_nth_child (saction->model, &iter, NULL, n))
 		while (gtk_list_store_remove (GTK_LIST_STORE (saction->model), &iter))
 			;
